@@ -17,6 +17,7 @@ if ($option_parser -> getoptions
 (
  \%option,
  'copy_name=s',
+ 'data_structure',
  'help',
  'starting_id=i',
  'table_name=s',
@@ -46,6 +47,7 @@ tree.pl [options]
 
 	Options:
 	-copy TableName
+	-data_structure
 	-help
 	-starting_id N
 	-table_name TableName
@@ -63,6 +65,18 @@ Exit value: 0.
 
 Copy the rows from the table specified by -table_name to the table specified by -copy.
 
+This option causes the -data_structure option to be ignored.
+
+When -copy is not used, the tree is displayed in 1 of 2 ways. See -data_structure for details.
+
+=item -data_structure
+
+This option is only used when the -copy option is not used.
+
+When -data_structure is used, the program displays a data structure suitable for encoding in JSON.
+
+When not used (and -copy is not used), the program pretty-prints the menu. This is the default output.
+
 =item -help
 
 Print help and exit.
@@ -77,6 +91,8 @@ Defaults to 1.
 
 The name of the table to process.
 
+This option is mandatory.
+
 =item -verbose
 
 Print progress messages.
